Module schema

Module schema 

rescript-schema validator generation with topological sorting

Functions

generate
generate_schema_only
get_dependencies
Extract type dependencies from a TypeDef
topological_sort
Topologically sort types so dependencies come before dependents
topological_sort_scc
Sort types into Strongly Connected Components (SCCs) in topological order Returns a list of components, where each component is a list of mutually recursive types.