rescript-schema validator generation with topological sorting
Functions
- generate
- generate_
schema_ only - get_
dependencies - Extract type dependencies from a TypeDef
- topological_
sort - Topologically sort types so dependencies come before dependents
- topological_
sort_ scc - Sort types into Strongly Connected Components (SCCs) in topological order Returns a list of components, where each component is a list of mutually recursive types.