pub fn topological_sort_scc(types: &[TypeDef]) -> Vec<Vec<&TypeDef>>Expand description
Sort types into Strongly Connected Components (SCCs) in topological order Returns a list of components, where each component is a list of mutually recursive types.